BUILD_BIT='64bit'
BUILD_CPU='Intel(R) Core(TM) i7-7700HQ CPU @ 2.80GHz'
BUILD_DATE='2019-05-09'
BUILD_MACHINE='x86_64'
BUILD_OS='Linux   '
BUILD_TIME='21:31'
COMPILER_VERSION='gcc (GCC) 8.3.0'
CYTHON_VERSION='0.29.7'
LINKER_VERSION='GNU ld (GNU Binutils) 2.32'
PYTHON_VERSION='2.7.16'
RELEASE_BUILD=True
lib_pycairo='1.18.0'
lib_pygobject='2.28.7'
lib_pygtk='2.24.0'
lib_vpx='1.8.0'
lib_x11='1.6.7'
lib_x264='0.157.2945 72db437'
lib_x265='3.0'
lib_xcomposite='0.4.5'
lib_xdamage='1.1.5'
lib_xext='1.3.4'
lib_xfixes='5.0.3'
lib_xkbfile='1.1.0'
lib_xrandr='1.5.2'
lib_xtst='1.2.3'
